@@ -11,7 +11,6 @@ def request_accesstoken(acc: str, pwd: str) -> str:
     data["version"] = "1"
     response = requests.get(url, data)
     if response.status_code == 200:
-        # print(response.json())
         accessToken = response.json().get("accessToken")
         return accessToken
 
@@ -21,13 +20,13 @@ class base:
         self.token = token
         self.app_secret = app_secret
 
-    def request(self, api_name=None, params={}, data={}, method="GET", url=None, json={}):
-        host_name = "http://bms.microc.cn/shopguide/api/"
+    def request(self, api_name=None, params={}, data={}, method="GET",
+                url=None, json={}, headers={}, api_prefix="api/"):
+        host_name = "http://bms.microc.cn/shopguide/"
         # host_name = "http://test.xxynet.com/shopguide/api/"
         if not url:
             if host_name not in api_name:
-                url = f"{host_name}{api_name}"
-
+                url = f"{host_name}{api_prefix}{api_name}"
         if "accessToken" not in params:
             # 没有token自动添加
             params["accessToken"] = self.token
@@ -37,21 +36,20 @@ class base:
 
         if method == "GET":
             params.update(data)
-            response = requests.get(url, params=params)
+            response = requests.get(url, params=params, headers=headers)
         elif method == "POST":
-            # print(method, data, json)
             if data:
-                response = requests.post(url, params=params, data=data)
+                response = requests.post(
+                    url, params=params, data=data, headers=headers)
             elif json:
-                response = requests.post(url, params=params, json=json)
+                response = requests.post(
+                    url, params=params, json=json, headers=headers)
             else:
                 raise ValueError("网络请求数据格式错误。")
 
         else:
             raise ValueError("请求方法错误。")
-        # print(url, response.status_code)
         if response.status_code == 200:
-            # print(data, response.json())
             return self.response(response.json())
 
     def response(self, response_raw):
