@@ -8,53 +8,6 @@ from loguru import logger
 from .base import base
 
 
-class appModCat(base):
-    """
-    模块分类管理
-    """
-
-    def __init__(self, token) -> None:
-        super().__init__(token)
-
-    def list(self):
-        data = dict(
-            page=1,
-            rows=100
-        )
-        return self.request(api_name="appModmoduleCateList.jhtml",
-                            data=data,
-                            method="POST")
-
-    def get_last_one(self):
-        rows = self.list().get("rows")
-        if rows:
-            return rows[-1]
-
-    def get_last_one_mod_id(self):
-        return self.get_last_one().get("id")
-
-    def create(self, cate_name, cate_order):
-        """
-        增加模块分类
-
-        """
-        data = {
-            "cateName": cate_name,
-            "cateOrder": cate_order,
-        }
-        response = self.request(api_name="appModmodfiModuleCate.jhtml",
-                                data=data,
-                                method="POST"
-                                )
-        info = response.get("info")
-        if info == "ok":
-            return self.get_last_one_mod_id()
-        else:
-            data["msg"] = "添加失败"
-            data["response"] = response
-            logger.error(data)
-
-
 class appMod(base):
     """
     app模块管理
@@ -63,6 +16,10 @@ class appMod(base):
     def __init__(self, token) -> None:
         super().__init__(token)
 
+    def request(self, **kwarg):
+        api_prefix = ""
+        return super().request(api_prefix=api_prefix, **kwarg)
+
     def list(self, mod_name=None):
         data = dict(
             page=1,
@@ -72,7 +29,7 @@ class appMod(base):
             data["param.modName"] = mod_name
         return self.request(api_name="appModlist.jhtml",
                             data=data,
-                                method="POST")
+                            method="POST")
 
     def get_last_one(self):
         rows = self.list().get("rows")
@@ -117,69 +74,59 @@ class appMod(base):
             logger.debug(data)
 
 
-def testcase1():
-    tk = "84d09f73a6f9965d3f4ddf131c2f3303_csb_web"
-    m = appModCat(tk)
-    response = m.create(
-        "任秋锴的测试模块分类2",
-        3,
-    )
-    print(response)
+class appModCat(base):
+    """
+    模块分类管理
+    """
 
+    def __init__(self, token) -> None:
+        super().__init__(token)
 
-def testcase11():
-    tk = "84d09f73a6f9965d3f4ddf131c2f3303_csb_web"
-    m = appModCat(tk)
-    response = m.get_last_one_mod_id()
-    print(response)
+    def request(self, **kwarg):
+        api_prefix = ""
+        headers = {
+            "Cookie": f"accessToken={self.token}"
+        }
+        return super().request(api_prefix=api_prefix,
+                               headers=headers,
+                               ** kwarg)
 
+    def list(self, mod_name=None):
+        data = dict(
+            page=1,
+            rows=100
+        )
+        if mod_name:
+            data["param.modName"] = mod_name
+        return self.request(api_name="appModmoduleCateList.jhtml",
+                            data=data,
+                            method="POST")
 
-def testcase2():
-    img_url = "http://supershoper.xxynet.com/csb1604498917482"
-    tk = "84d09f73a6f9965d3f4ddf131c2f3303_csb_web"
-    m = appMod(tk)
-    response = m.create(
-        module_name="任秋锴的测试3",
-        module_code="Rqk005",
-        cate_id=169,
-        img_url=img_url,
-        disp_order=3,
-    )
-    print(response)
+    def get_last_one(self):
+        rows = self.list().get("rows")
+        if rows:
+            return rows[-1]
 
+    def get_last_one_mod_id(self):
+        return self.get_last_one().get("id")
 
-def testcase21():
-    tk = "84d09f73a6f9965d3f4ddf131c2f3303_csb_web"
-    m = appMod(tk)
-    response = m.get_last_one_mod_id()
-    print(response)
+    def create(self, cate_name, cate_order):
+        """
+        增加模块分类
 
-
-def testcase3():
-    tk = "84d09f73a6f9965d3f4ddf131c2f3303_csb_web"
-    img_url = "http://supershoper.xxynet.com/csb1604498917482"
-    m = appMod(tk)
-    c = appModCat(tk)
-    cate_id = c.create(
-        "自动添加001",
-        3,
-    )
-    response = m.create(
-        module_name="自动添加模块",
-        module_code="Rqk005",
-        cate_id=cate_id,
-        img_url=img_url,
-        disp_order=3,
-    )
-    print(response)
-
-
-def testcase4():
-    tk = "4be768e606ca3e349df2a9b626061186_moban004_web"
-    m = appMod(tk)
-    response = m.delete_all()
-    print(response)
-
-
-if __name__ == "__main__":
-    testcase4()
+        """
+        data = {
+            "cateName": cate_name,
+            "cateOrder": cate_order,
+        }
+        response = self.request(api_name="appModmodfiModuleCate.jhtml",
+                                data=data,
+                                method="POST"
+                                )
+        info = response.get("info")
+        if info == "ok":
+            return self.get_last_one_mod_id()
+        else:
+            data["msg"] = "添加失败"
+            data["response"] = response
+            logger.error(data)
